#[non_exhaustive]pub struct Transform(pub u32);Expand description
transformation applied to buffer contents
This describes transformations that clients and compositors apply to buffer contents.
The flipped values correspond to an initial flip around a vertical axis followed by rotation.
The purpose is mainly to allow clients to render accordingly and tell the compositor, so that for fullscreen surfaces, the compositor will still be able to scan out directly from client surfaces.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations
Sourceimpl Transform
impl Transform
Sourcepub const Flipped180: Self
pub const Flipped180: Self
flip and rotate 180 degrees counter-clockwise
Sourcepub const Flipped270: Self
pub const Flipped270: Self
flip and rotate 270 degrees counter-clockwise